# Class: bind
#
# This module manages bind
#
# Parameters:
#
# Actions:  Installs and configures bind master dns server in a chroot environment along with ddns updates (from dhcpd etc)
#
# Requires:
#
# Sample Usage:  include bind
#
# [Remember: No empty lines between comments and class definition]
class bind {

	# Set variables for configuration template files
	$dnsserial = "2011110100"     	# change serial everytime templates are updated
									# format is:  year month day  count increment.  Increment by 3 ie: 00 > 03 > 06 etc
								
	$dnsemail = "sysadmin@EXAMPLE.com"	# BIND administrator email address

    # Install the DNS and DNSSEC bind packages and related files
    $packagelist = ["bind", "bind-chroot", "bind-libs", "bind-utils", "curl", "python-dns"] 
    
    package {
		$packagelist: ensure => installed
    }

    #ensure bind is installed and running

    service {
		'named': enable =>true,
		ensure =>running,
		hasstatus =>true,
		require =>Package[bind],
    }


	# Tell bind to start in chroot 
    file { "/etc/sysconfig/named":
        owner => "root",
		group => "named",
		mode => 0640,
		content => template("bind/named-sysconfig"),
		notify =>Service[named],
		require =>Package[bind-chroot],
    }

	# Master configuration file for bind
    file { "/var/named/chroot/etc/named.conf": owner =>root,
		group  => root,
		mode   => 644,
		content => template("bind/named.conf"),
		notify => Service[named],
		require =>Package[bind-chroot],
    }


	# Create directory for our master zone files
    file { "/var/named/chroot/var/named/master":
        ensure  => directory, 
        owner   => "root",
		group   => "named",
		mode    => 0664, 
		source  => "puppet://$server/modules/bind/master-empty",
		require =>Package[bind-chroot],
    }

	
	# recursivly populate the standard zone and hints files
    file { "/var/named/chroot/var/named/standard":
        ensure  => directory, 
        recurse => true, 
        owner   => "root",
		group   => "named",
		mode    => 0664, 
		source  => "puppet://$server/modules/bind/standard",
		require => Package[bind-chroot],
    }

	# Master zone file for EXAMPLE.com internal network
    file {
		"/var/named/chroot/var/named/master/db.EXAMPLE.com":
        ensure  => present,
        owner   => "root",
		group   => "root",
		mode    => 664,
		content => template("bind/db.EXAMPLE.com.erb"),
		notify  => Service[named],
		require => File["/var/named/chroot/var/named/master"],
    }

	# Master reverse lookup file for EXAMPLE.com zone
    file {
		"/var/named/chroot/var/named/master/db.192.168.168":
        ensure  => present,
        owner   => "root",
		group   => "root",
		mode    => 664,
		content => template("bind/db.192.168.168.erb"),
		notify  => Service[named],
		require => File["/var/named/chroot/var/named/master"],
    }

}
